sqlobject.firebird.firebirdconnection module — SQLObject 3.9.1 documentation

# sqlobject.firebird.firebirdconnection module

class `sqlobject.firebird.firebirdconnection.` `FirebirdConnection`(host, db, port='3050', user='sysdba', password='masterkey', autoCommit=1, dialect=None, role=None, charset=None, **kw)

  Bases: `sqlobject.dbconnection.DBAPI`

  `addColumn`(tableName, column)
  `columnsFromSchema`(tableName, soClass)

    Look at the given table and create Col instances (or subclasses of Col) for the fields it finds in that table.

  `createColumn`(soClass, col)
  `createEmptyDatabase`()

    Create an empty database.

  `createIDColumn`(soClass)
  `createIndexSQL`(soClass, index)
  `createReferenceConstraint`(soClass, col)
  `createTable`(soClass)
  `dbName` = 'firebird'
  `delColumn`(sqlmeta, column)
  `dropDatabase`()
  `dropTable`(tableName, cascade=False)
  `guessClass`(t, flength, fCharset, fscale=None)

    An internal method that tries to figure out what Col subclass is appropriate given whatever introspective information is available – both very database-specific.

  `joinSQLType`(join)
  `limit_re` = re.compile('^\\s*(select )(.*)', re.IGNORECASE)
  `makeConnection`()
  `readDefaultEncodingFromDB`()
  `schemes` = ['firebird']
  `supportTransactions` = False
  `tableExists`(tableName)